@@ -107,6 +107,7 @@ static constexpr const RemarkData remarks_map[] = {
     { "A", "ER", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
     { "A", "EXTERNAL_ID", IgnoreRemark, Feature::NoFeature, Feature::Unknown },
     { "A", "FB", FeatureRemark, Feature::BikeStorage, Feature::Limited },
+    { "A", "FH", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
     { "A", "FK", FeatureRemark, Feature::BikeStorage, Feature::Limited },
     { "A", "FR", FeatureRemark, Feature::BikeStorage, Feature::Conditional },
     { "A", "FS", FeatureRemark, Feature::BikeStorage, Feature::Conditional },
@@ -130,6 +131,7 @@ static constexpr const RemarkData remarks_map[] = {
     { "A", "QP", FeatureRemark, Feature::Restaurant, Feature::Available },
     { "A", "RG", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
     { "A", "RO", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
+    { "A", "RZ", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
     { "A", "SA", FeatureRemark, Feature::ToddlerArea, Feature::Limited },
     { "A", "SI", FeatureRemark, Feature::WheelchairAccessible, Feature::Limited },
     { "A", "SN", FeatureRemark, Feature::Restaurant, Feature::Available },
@@ -159,8 +161,11 @@ static constexpr const RemarkData remarks_map[] = {
     { "A", "ia", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
     { "A", "ic", FeatureRemark, Feature::Restaurant, Feature::Available },
     { "A", "ie", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
+    { "A", "in", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
     { "A", "kx", FeatureRemark, Feature::PowerSockets, Feature::Available },
     { "A", "lb", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
+    { "A", "mG", FeatureRemark, Feature::BikeStorage, Feature::Conditional },
+    { "A", "mg", FeatureRemark, Feature::WheelchairAccessible, Feature::Conditional },
    // ZVV: pointless note about checking intermediate stops for more details
     { "A", "moreAttr", IgnoreRemark, Feature::NoFeature, Feature::Unknown },
     { "A", "yh", FeatureRemark, Feature::WiFi, Feature::Available },
@@ -225,7 +230,7 @@ static std::vector<Message> parseRemarks(const QJsonArray &remL)
             }
             case UndefinedRemark:
                 if (type == 'A'_L1 && (code.startsWith("text.occup.loc."_L1) || code.startsWith("text.occup.jny."_L1))) {
-                    static const QRegularExpression rx(u"\\.(max|1st|2nd)\\.1([1-4])$"_s);
+                    static const QRegularExpression rx(u"\\.(max|1st|2nd)(?:\\.rt)?\\.1([1-4])$"_s);
                     const auto match = rx.match(code);
                     if (match.hasMatch()) {
                         const auto r = match.captured(2).toInt();
