@@ -109,6 +109,8 @@ bool LTGLinkBackend::queryJourney(const JourneyRequest &req, JourneyReply *reply
                     auto scheduledArrivalTime = QDateTime::fromString(sectionJson[u"Destination"][u"PlannedArrivalDateTime"].toString(), Qt::ISODate);
                     scheduledArrivalTime.setTimeZone(destinationTimeZone);
 
+                    auto note = sectionJson[u"Trip"][u"Name"].toString();
+
                     // Filter out results that don't match the selected time frame
                     if (!LocalBackendUtils::isInSelectedTimeframe(actualDepartureTime, actualArrivalTime, req)) {
                         continue;
@@ -119,7 +121,12 @@ bool LTGLinkBackend::queryJourney(const JourneyRequest &req, JourneyReply *reply
 
                     Line line;
                     line.setName(lineNumber);
-                    line.setMode(transportationType == u"LINE_TRANSPORTATION_TYPE.TRAIN" ? Line::Mode::Train : Line::Mode::Unknown);
+                    if (transportationType == u"LINE_TRANSPORTATION_TYPE.TRAIN" || transportationType.isNull()) {
+                        line.setMode(Line::Mode::Train);
+                    } else {
+                        qDebug() << "ltglink: Unknown transportation type" << transportationType << ", falling back to train";
+                        line.setMode(Line::Mode::Train);
+                    }
 
                     Route route;
                     route.setLine(line);
@@ -134,6 +141,10 @@ bool LTGLinkBackend::queryJourney(const JourneyRequest &req, JourneyReply *reply
                     section.setMode(JourneySection::PublicTransport);
                     section.setRoute(route);
 
+                    if (!note.isEmpty()) {
+                        section.setNotes({note});
+                    }
+
                     sections.push_back(std::move(section));
                 }
 
@@ -175,10 +186,12 @@ bool LTGLinkBackend::queryJourney(const JourneyRequest &req, JourneyReply *reply
                 (*runningRequests)--;
 
                 if (*runningRequests == 0) {
-                    Attribution attribution;
-                    attribution.setName(QStringLiteral("LTG Link"));
-                    attribution.setUrl(QUrl(QStringLiteral("https://ltglink.lt")));
-                    addAttributions(reply, {attribution});
+                    if (!journeys->empty()) {
+                        Attribution attribution;
+                        attribution.setName(QStringLiteral("LTG Link"));
+                        attribution.setUrl(QUrl(QStringLiteral("https://ltglink.lt")));
+                        addAttributions(reply, {attribution});
+                    }
 
                     addResult(reply, this, std::move(*journeys));
                 }
